.. _child_example_one-name:

!!!!!!!!!!!!!!!!!
child_example_one
!!!!!!!!!!!!!!!!!

.. meta::
   :keywords: child_example_one, first, child, page

.. index:: child_example_one, first, child, page

.. _child_example_one-title:

First Child Example Page
########################

.. contents::
   :local:

.. meta::
   :keywords: links

.. index:: links

.. _child_example_one@Links:

Links
*****
- :ref:`parent<toc_list_example-title>`
- :ref:`second child<child_example_two-title>`

.. _child_example_one@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/children.xrst
   :language: rst
